yakumo.smoketest

Package yakumo :: Module smoketest |
[hide private]
[frames] | no frames]

# Module smoketest

source code

Functions | [hide private]
cleaner(resource) | source code
get_random_str(prefix="test") | source code
test(label, condition) | source code
show_test_summary() | source code

Variables | [hide private]
| SOURCE = `"abcdefghijklmnopqrstuvwxyz" "ABCDEFGHIJKLMNOPQRSTUVW`...``
| TEST_LOGS = `[]`
| ENVIRONMENT_VARIABLES = `{'os_cloud': 'OS_CLOUD', 'os_cert': 'O`...``
| kwargs = `{dest: os.environ.get(env) for dest, env in ENVIRONME`...``
| parser = `argparse.ArgumentParser()`
| cloud_config = `os_client_config.OpenStackConfig()`
| options = `parser.parse_args()`
| c = `Client(** options.__dict__)`
| LOG = `logging.getLogger(os.path.basename(sys.argv [0]))`
| ch = `logging.StreamHandler()`
| formatter = `logging.Formatter('%(asctime)s %(name)s %(levelnam`...``

Function Details | [hide private]

### cleaner(resource) | source code
Decorators: `@contextmanager`

Variables Details | [hide private]

  ### SOURCE Value:
      "abcdefghijklmnopqrstuvwxyz" "ABCDEFGHIJKLMNOPQRSTUVWXYZ" "0123456789"

  ### ENVIRONMENT_VARIABLES Value:
      {'os_cloud': 'OS_CLOUD', 'os_cert': 'OS_CERT', 'os_cacert': 'OS_CACERT
      ', 'os_region_name': 'OS_REGION_NAME', 'os_interface': 'OS_INTERFACE',
       'os_key': 'OS_KEY', 'os_auth_type': 'OS_AUTH_TYPE',}

  ### kwargs Value:
      {dest: os.environ.get(env) for dest, env in ENVIRONMENT_VARIABLES.item
      s()}

  ### formatter Value:
      logging.Formatter('%(asctime)s %(name)s %(levelname)s %(message)s')